@@ -85,14 +85,9 @@ class ABCConnection(abc.ABC):
         self.database = database
         self.logger: logging.Logger = database.logger
         self.transactions: t.List[ABCTransaction] = []
-        self._conn = None
+        self._conn: t.Any = None
         self._lock: asyncio.Lock = self.lock_cls()
 
-    @property
-    def conn(self):
-        assert self.is_ready, "Connection is not acquired"
-        return self._conn
-
     @property
     def is_ready(self) -> bool:
         return self._conn is not None
