@@ -3,9 +3,9 @@ from __future__ import annotations
 import typing as t
 
 import asyncpg
-from re import compile as re
 
 from . import ABCDatabaseBackend, ABCConnection, ABCTransaction, RE_PARAM
+from .common import PGReplacer, pg_parse_status
 
 
 class Transaction(ABCTransaction):
@@ -15,7 +15,7 @@ class Transaction(ABCTransaction):
     @property
     def trans(self) -> asyncpg.transactions.Transaction:
         if self._trans is None:
-            self._trans = self.connection.conn.transaction()
+            self._trans = self.connection._conn.transaction()
         return self._trans
 
     async def _start(self):
@@ -33,35 +33,35 @@ class Connection(ABCConnection):
     transaction_cls = Transaction
 
     async def _execute(self, query: str, *params, **options) -> t.Any:
-        conn: asyncpg.Connection = self.conn
+        conn: asyncpg.Connection = self._conn
         status = await conn.execute(query, *params, **options)
-        return parse_status(status)
+        return pg_parse_status(status)
 
     async def _executemany(self, query: str, *params, **options) -> t.Any:
-        conn: asyncpg.Connection = self.conn
+        conn: asyncpg.Connection = self._conn
         return await conn.executemany(query, params, **options)
 
     async def _fetchall(self, query: str, *params, **options) -> t.List[asyncpg.Record]:
-        conn: asyncpg.Connection = self.conn
+        conn: asyncpg.Connection = self._conn
         return await conn.fetch(query, *params, **options)
 
     async def _fetchmany(self, size: int, query: str,
                          *params, **options) -> t.List[asyncpg.Record]:
-        conn: asyncpg.Connection = self.conn
+        conn: asyncpg.Connection = self._conn
         async with conn.transaction():
             cur = await conn.cursor(query, *params)
             return await cur.fetch(size)
 
     async def _fetchone(self, query: str, *params, **options) -> t.Optional[asyncpg.Record]:
-        conn: asyncpg.Connection = self.conn
+        conn: asyncpg.Connection = self._conn
         return await conn.fetchrow(query, *params, **options)
 
     async def _fetchval(self, query: str, *params, column: t.Any = 0, **options) -> t.Any:
-        conn: asyncpg.Connection = self.conn
+        conn: asyncpg.Connection = self._conn
         return await conn.fetchval(query, *params, column=column, **options)
 
     async def _iterate(self, query: str, *params, **options) -> t.AsyncIterator[asyncpg.Record]:
-        conn: asyncpg.Connection = self.conn
+        conn: asyncpg.Connection = self._conn
         async with conn.transaction():
             async for rec in conn.cursor(query, *params):
                 yield rec
@@ -78,7 +78,7 @@ class Backend(ABCDatabaseBackend):
     def __convert_sql__(self, sql: t.Any) -> str:
         sql = str(sql)
         if self.convert_params:
-            sql = RE_PARAM.sub(Replacer(), sql)
+            sql = RE_PARAM.sub(PGReplacer(), sql)
 
         return sql
 
@@ -107,26 +107,3 @@ class Backend(ABCDatabaseBackend):
         pool = self.pool
         assert pool is not None, "Database is not connected"
         await pool.release(conn)
-
-
-class Replacer:
-
-    __slots__ = ('num',)
-
-    def __init__(self):
-        self.num = 0
-
-    def __call__(self, match):
-        self.num += 1
-        return f"{match.group(1)}${self.num}"
-
-
-def parse_status(status: str) -> t.Union[str, int]:
-    operation, params = status.split(' ', 1)
-    if operation in {'INSERT'}:
-        return params.split()[0]
-
-    if operation in {'UPDATE', 'DELETE'}:
-        return int(params.split()[0])
-
-    return status
